@@ -8,6 +8,7 @@ use base qw(Test::Class);
 use Sub::Override;
 use Test::Most;
 
+#{{{ sub make_fixture
 sub make_fixture : Test(setup => 1)
 {
     my $self = shift;
@@ -20,7 +21,9 @@ sub make_fixture : Test(setup => 1)
         }
     );
 }
+#}}}
 
+#{{{ sub TEST__IS_ONE_OF
 sub TEST__IS_ONE_OF : Test(4)
 {
     is(
@@ -47,7 +50,9 @@ sub TEST__IS_ONE_OF : Test(4)
         "Doesn't find element, even if there's more than one element in the list.",
     );
 }
+#}}}
 
+#{{{ sub TEST__CHECK_PROJECT_ID
 sub TEST__CHECK_PROJECT_ID : Test(3)
 {
     is(
@@ -68,7 +73,9 @@ sub TEST__CHECK_PROJECT_ID : Test(3)
         "'a' is not a valid project id",
     );
 }
+#}}}
 
+#{{{ sub TEST__CHECK_STORY_ID
 sub TEST__CHECK_STORY_ID : Test(3)
 {
     is(
@@ -89,7 +96,9 @@ sub TEST__CHECK_STORY_ID : Test(3)
         "'a' is not a valid story id",
     );
 }
+#}}}
 
+#{{{ sub TEST__DO_REQUEST__ARRAYIFIES_ELEMENTS_THAT_COULD_APPEAR_MORE_THAN_ONCE
 sub TEST__DO_REQUEST__ARRAYIFIES_ELEMENTS_THAT_COULD_APPEAR_MORE_THAN_ONCE : Test(4)
 {
     my $self = shift;
@@ -149,7 +158,9 @@ sub TEST__DO_REQUEST__ARRAYIFIES_ELEMENTS_THAT_COULD_APPEAR_MORE_THAN_ONCE : Tes
         '$response->{story}->[0]->{labels}->{label}',
     );
 }
+#}}}
 
+#{{{ sub TEST__SANITIZE_STORY_XML
 sub TEST__SANITIZE_STORY_XML : Test(4)
 {
     my $self = shift;
@@ -250,7 +261,9 @@ sub TEST__SANITIZE_STORY_XML : Test(4)
         '$sanitized_response ok',
     );
 }
+#}}}
 
+#{{{ sub TEST_PROJECT_DETAILS__BASE_CASE
 sub TEST_PROJECT_DETAILS__BASE_CASE : Test(3)
 {
     my $self = shift;
@@ -289,7 +302,9 @@ sub TEST_PROJECT_DETAILS__BASE_CASE : Test(3)
         "project_details response ok"
     );
 }
+#}}}
 
+#{{{ sub TEST_PROJECT_DETAILS__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE
 sub TEST_PROJECT_DETAILS__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
 {
     my $self = shift;
@@ -324,7 +339,9 @@ sub TEST_PROJECT_DETAILS__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
         "project_details response ok"
     );
 }
+#}}}
 
+#{{{ sub TEST_SHOW_STORY__BASE_CASE
 sub TEST_SHOW_STORY__BASE_CASE : Test(3)
 {
     my $self = shift;
@@ -392,7 +409,9 @@ sub TEST_SHOW_STORY__BASE_CASE : Test(3)
         'show_story ok',
     );
 }
+#}}}
 
+#{{{ sub TEST_SHOW_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE
 sub TEST_SHOW_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
 {
     my $self = shift;
@@ -424,8 +443,10 @@ sub TEST_SHOW_STORY__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
         'show_story ok',
     );
 }
+#}}}
 
-sub TEST_ALL_STORIES_BASE_CASE : Test(3)
+#{{{ sub TEST_ALL_STORIES__BASE_CASE
+sub TEST_ALL_STORIES__BASE_CASE : Test(3)
 {
     my $self = shift;
 
@@ -540,7 +561,9 @@ sub TEST_ALL_STORIES_BASE_CASE : Test(3)
         'all_stories ok',
     );
 }
+#}}}
 
+#{{{ sub TEST_ALL_STORIES__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE
 sub TEST_ALL_STORIES__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
 {
     my $self = shift;
@@ -572,21 +595,45 @@ sub TEST_ALL_STORIES__HANDLES_WHEN_SUCCESS_IS_NOT_TRUE : Test(3)
         'show_story ok',
     );
 }
+#}}}
 
-sub teardown : Test(teardown)
+#{{{ sub TEST_STORIES_FOR_FILTER__URL_ENCODES_FILTER
+sub TEST_STORIES_FOR_FILTER__URL_ENCODES_FILTER : Test(2)
 {
     my $self = shift;
 
-    $self->{'override'} = undef;
-};
+    my $query_string;
 
-1;
+    $self->{'override'}->replace(
+        'WWW::PivotalTracker::_do_request' => sub($$$$;$) {
+            $query_string = $_[2];
 
-__END__
+            return {
+                success => 'false',
+                errors  => [ 'Dummy Data', ],
+            };
+        }
+    );
 
+    use_ok('WWW::PivotalTracker', qw/ stories_for_filter /);
+
+    my $response = stories_for_filter('c0ffe', 1, 'This should be URL <Encoded>');
+
+    eq_or_diff($query_string, "projects/1/stories?filter=This%20should%20be%20URL%20%3CEncoded%3E", "stories_for_filter URL encodes filter");
+}
+#}}}
+
+#{{{ sub TEST_STORIES_FOR_FILTER__SANITIZES_STORY_XML
+sub TEST_STORIES_FOR_FILTER__SANITIZES_STORY_XML : Test(3)
+{
+    my $self = shift;
+
+    $self->{'override'}->replace(
+        'WWW::PivotalTracker::_post_request' => sub($$) {
+            return <<"            HERE";
 <?xml version="1.0" encoding="UTF-8"?>
 <response success="true">
-  <message>2 stories found</message>
+  <message>2 stories found for filter 'requested_by:"Jacob Helwig"'</message>
   <stories count="2">
     <story>
       <id type="integer">320532</id>
@@ -624,8 +671,88 @@ __END__
       <name>Story!</name>
       <requested_by>Jacob Helwig</requested_by>
       <created_at>Dec 20, 2008</created_at>
+      <labels type="array">
+        <label>needs feedback</label>
+      </labels>
     </story>
   </stories>
 </response>
+            HERE
+        }
+    );
 
-# vim: set tabstop=4 shiftwidth=4:
+    use_ok('WWW::PivotalTracker', qw/ stories_for_filter /);
+
+    my $response = stories_for_filter('c0ffe', 1, 'requested_by:"Jacob Helwig"');
+    isa_ok($response, 'HASH', 'stories_for_filter return value');
+
+    eq_or_diff(
+        $response,
+        {
+            message => q{2 stories found for filter 'requested_by:"Jacob Helwig"'},
+            success => 'true',
+            stories => [
+                {
+                  created_at    => 'Dec 20, 2008',
+                  current_state => 'unscheduled',
+                  deadline      => 'Dec 31, 2008',
+                  description   => undef,
+                  estimate      => '-1',
+                  id            => '320532',
+                  labels        => undef,
+                  name          => 'Release 1',
+                  requested_by  => 'Jacob Helwig',
+                  story_type    => 'release',
+                  url           => 'https://www.pivotaltracker.com/story/show/320532',
+                  notes => [
+                    {
+                      author => 'Jacob Helwig',
+                      date   => 'Dec 20, 2008',
+                      id     => '209033',
+                      text   => 'Comment!'
+                    },
+                    {
+                      author => 'Jacob Helwig',
+                      date   => 'Dec 20, 2008',
+                      id     => '209034',
+                      text   => 'Another comment!'
+                    }
+                  ],
+                },
+                {
+                  created_at    => 'Dec 20, 2008',
+                  current_state => 'unscheduled',
+                  deadline      => undef,
+                  description   => undef,
+                  estimate      => '-1',
+                  id            => '320008',
+                  name          => 'Story!',
+                  notes         => undef,
+                  requested_by  => 'Jacob Helwig',
+                  story_type    => 'feature',
+                  url           => 'https://www.pivotaltracker.com/story/show/320008',
+                  labels => [
+                    'needs feedback'
+                  ],
+                }
+            ],
+        },
+        'stories_for_filter sanitized story XML ok',
+    );
+}
+#}}}
+
+#{{{ sub teardown
+sub teardown : Test(teardown)
+{
+    my $self = shift;
+
+    $self->{'override'} = undef;
+}
+#}}}
+
+1;
+
+__END__
+
+# vim: set tabstop=4 shiftwidth=4 fdm=marker:
